import { Injectable } from "@angular/core";
import { Platform } from "ionic-angular";

const win: any = window;

@Injectable()
export class DBProvider {
	private _dbPromise: Promise<any>;
  private platform = new Platform();
	constructor(public dbName: string) {

    this._dbPromise = new Promise((resolve, reject) => {
			try {
				let _db: any;
				if (this.platform.is('cordova') && win.sqlitePlugin) {
					//FOR MOBILE DEVICE
					_db = win.sqlitePlugin.openDatabase({
						name: this.dbName,
						location: 'default'
					});
				} else {
					//FOR WEBSQL
					console.warn('Storage: SQLite plugin not installed, falling back to WebSQL. Make sure to install cordova-sqlite-storage in production!');
					_db = win.openDatabase(this.dbName, '1.0', 'database', 5 * 1024 * 1024);
				}
				resolve(_db);
			} catch (err) {
				reject({ err: err });
			}
		});
	}
	query(query: string, params: any[] = []): Promise<any> {
		return new Promise((resolve, reject) => {
			try {
				this._dbPromise.then(db => {
					db.transaction((tx: any) => {
						tx.executeSql(query, params,
							(tx: any, res: any) => resolve({ tx: tx, res: res }),
							(tx: any, err: any) => reject({ tx: tx, err: err }));
					},
						(err: any) => reject({ err: err }));
				});
			} catch (err) {
				reject({ err: err });
			}
		});
	}
}
